gzip: fix bug in unpack EOB check
[debian/gzip] / zip.c
diff --git a/zip.c b/zip.c
index af51f98e1366aaf94afdb77452c95089154aa3c1..eb5661ff85e0806fbd8b087ebd07290938c37c0e 100644 (file)
--- a/zip.c
+++ b/zip.c
@@ -60,9 +60,9 @@ int zip(in, out)
       stamp = time_stamp.tv_sec;
     else
       {
/* It's intended that time stamp 0 generates this warning,
            since gzip format reserves 0 for something else.  */
-        warning ("file time stamp out of range for gzip format");
+        warning ("file timestamp out of range for gzip format");
         stamp = 0;
       }
     put_long (stamp);
@@ -60,9 +60,9 @@ int zip(in, out)
     else
       {
-        /* It's intended that time stamp 0 generates this warning,
+        /* It's intended that timestamp 0 generates this warning,
            since gzip format reserves 0 for something else.  */